public inbox for mauve-patches@sourceware.org
 help / color / mirror / Atom feed
* FYI: Pass incoming event object directly to the target action.
@ 2009-07-24 12:38 Mario Torre
  0 siblings, 0 replies; only message in thread
From: Mario Torre @ 2009-07-24 12:38 UTC (permalink / raw)
  To: mauve-patches

[-- Attachment #1: Type: text/plain, Size: 708 bytes --]

2009-07-09  Mario Torre  <neugens@aicas.com>

     * gnu/testlet/java/beans/EventHandler/check14c.java:
     Pass incoming event object directly to the target action.

Cheers,
Mario
-- 
Mario Torre, Software Developer, http://www.jroller.com/neugens/
aicas Allerton Interworks Computer Automated Systems GmbH
Haid-und-Neu-Straße 18 * D-76131 Karlsruhe * Germany
http://www.aicas.com   * Tel: +49-721-663 968-44
pgp key: http://subkeys.pgp.net/ PGP Key ID: 80F240CF
Fingerprint: BA39 9666 94EC 8B73 27FA  FC7C 4086 63E3 80F2 40CF

USt-Id: DE216375633, Handelsregister HRB 109481, AG Mannheim
Geschäftsführer: Dr. James J. Hunt

Please, support open standards:
http://endsoftpatents.org/


[-- Attachment #2: 2009-07-24-beans-event-handler-1.6.patch --]
[-- Type: text/x-patch, Size: 2187 bytes --]

# This patch file was generated by NetBeans IDE
# This patch can be applied using context Tools: Apply Diff Patch action on respective folder.
# It uses platform neutral UTF-8 encoding.
# Above lines and this line are ignored by the patching process.
Index: mauve/gnu/testlet/java/beans/EventHandler/check14c.java
--- mauve/gnu/testlet/java/beans/EventHandler/check14c.java Base (1.3)
+++ mauve/gnu/testlet/java/beans/EventHandler/check14c.java Locally Modified (Based On 1.3)
@@ -81,11 +81,10 @@
 
 	public void test(TestHarness harness) {
 
 		// The first test checks whether a ArrayIndexOutOfBoundsException is
 		// thrown
 		// when the targetMethod cannot be found (Especially because of missing
-		// access
-		// rights).
+		// access rights).
+                // JDK 1.4 and 1.5 erroneously throw an ArrayIndexOutOfBoundsException.
 		Listener l = (Listener) EventHandler.create(Listener.class, this,
 				"targetMethod");
 
@@ -93,7 +92,7 @@
 		try {
 			l.listen();
 		} catch (Exception e) {
-			correctException = e.getClass() == ArrayIndexOutOfBoundsException.class;
+			correctException = e.getClass() == RuntimeException.class;
 		}
 		harness.check(correctException, true, "missing target method");
 
@@ -146,10 +145,11 @@
 		// One may think that a creation like this will forward the Event
 		// instance to the 'setEventProperty'
 		// method but this is wrong and will cause a
-		// ArrayIndexOutOfBoundsException to be as if could not
+		// RuntimeException to be as if could not
 		// find a method. In other words: If no property is defined action will
 		// never be treated as a
 		// property but always like a method name.
+                // JDK 1.4 and 1.5 erroneously throw an ArrayIndexOutOfBoundsException.
 		l2 = (Listener2) EventHandler.create(Listener2.class, this,
 				"eventProperty");
 
@@ -157,7 +157,7 @@
 		try {
 			l2.listen(new Event());
 		} catch (Exception e) {
-			correctException = e.getClass() == ArrayIndexOutOfBoundsException.class;
+			correctException = e.getClass() == RuntimeException.class;
 		}
 		harness.check(correctException, true, "action is method");
 

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2009-07-24 12:38 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -81,11 +81,10 @@
 	public void test(TestHarness harness) {
 
-		// The first test checks whether a ArrayIndexOutOfBoundsException is
-		// thrown
+		// The first test checks whether a RuntimeException is thrown
 		// when the targetMethod cannot be found (Especially because of missing
2009-07-24 12:38 FYI: Pass incoming event object directly to the target action Mario Torre

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).